@@ -3,36 +3,41 @@ package FFI::C::FFI;
 use strict;
 use warnings;
 use FFI::Platypus 1.24;
+use constant ();
 use base qw( Exporter );
 
 # ABSTRACT: Private module for FFI::C
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 
 our @EXPORT_OK = qw( malloc free memset memcpy_addr );
 
-my $ffi;
-BEGIN { $ffi = FFI::Platypus->new( api => 1, lib => [undef] ) };
+my $ffi = FFI::Platypus->new( api => 1, lib => [undef] );
 
-use constant memcpy_addr => FFI::Platypus->new( lib => [undef] )->find_symbol( 'memcpy' );
+constant->import( memcpy_addr => $ffi->find_symbol( 'memcpy' ) );
 
-sub malloc ($)
-{
-  $ffi->function( malloc => ['size_t'] => 'opaque' )
-      ->call(@_);
-}
+$ffi->attach( malloc => ['size_t']                => 'opaque', '$'   );
+$ffi->attach( free   => ['opaque']                => 'void',   '$'   );
+$ffi->attach( memset => ['opaque','int','size_t'] => 'opaque', '$$$' );
 
-sub free ($)
-{
-  $ffi->function( free => ['opaque'] => 'void' )
-      ->call(@_);
-}
-
-sub memset ($$$)
-{
-  $ffi->function( memset => ['opaque','int','size_t'] => 'opaque' )
-      ->call(@_);
-}
+## should this be configurable for when we hunt for memory leaks?
+#sub malloc ($)
+#{
+#  $ffi->function( malloc => ['size_t'] => 'opaque' )
+#      ->call(@_);
+#}
+#
+#sub free ($)
+#{
+#  $ffi->function( free => ['opaque'] => 'void' )
+#      ->call(@_);
+#}
+#
+#sub memset ($$$)
+#{
+#  $ffi->function( memset => ['opaque','int','size_t'] => 'opaque' )
+#      ->call(@_);
+#}
 
 1;
 
@@ -48,7 +53,7 @@ FFI::C::FFI - Private module for FFI::C
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -94,7 +99,7 @@ Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Graham Ollis.
+This software is copyright (c) 2020,2021 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
